import smtplib
import datetime
from email.message import EmailMessage
from email.utils import formatdate
import requests

def do_work():
    with open("/srv/dokuwiki/data/data/pages/intern/diskussionsthemen.txt") as fp:
        raw = fp.read().split('\n')

        # Extract Themen 
        firstline = 0
        lastline = 0
        for index, line in enumerate(raw):
            # Start marker
            if "====== 1." in line:
                firstline = index + 1
                continue
            
            # End marker
            if "====== 2." in line:
                lastline = index
                break
        
        # Remove empty lines from topics
        topics = []
        for extracted in raw[firstline:lastline]:
            if extracted != '':
                topics.append(extracted)

        # There are no topics - just exit
        if (len(topics) == 0):
            return True

        # calculate date of next tuesday
        d = datetime.date.today()
        while d.strftime('%a') != 'Tue':
            d += datetime.timedelta(1)

        # mail template 
        mail = f"""
    Liebe Zonies,
        
    es gibt wieder Themen die im Plenum besprochen werden sollen. Der nächste
    Reguläre Termin ist am nächsten Dienstag ({str(d)}) um 20:00.
    Im Wiki (https://wiki.warpzone.ms/intern:diskussionsthemen#diskussionsthemen_naechstes_plenum_automatische_einladung)
    stehen folgende Themen:

    {chr(10).join(topics)}

    Die Teilnahme ist natürlich auch remote möglich unter
    https://jitsi.dorf-post.de/warpzone-plenum möglich.

    Viele Grüße und bis Dienstag,

    sendmail_plenum.py
    """

        msg = EmailMessage()
        msg['Subject'] = f'Aktuelle Plenumsthemen für Dienstag ({str(d)} 20:00)'
        msg['From'] = '{{noreply_email_user}}'
        msg['To'] = 'intern@warpzone.ms'
        msg['Date'] = formatdate(localtime=True)
        msg.set_content(mail)
        
        server = smtplib.SMTP('{{smtp_host}}', {{smtp_port}})
        server.starttls()
        server.login("{{noreply_email_user}}", "{{noreply_email_pass}}")
        server.send_message(msg)
        server.quit()
    return True

success = False
try:
    success = do_work()
finally:
    requests.get("{{ healthchecks_url }}" if success else "{{ healthchecks_url }}" + "/fail")
